<?php

namespace Drupal\access_filter\Plugin\AccessFilter\Condition;

use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Plugin\PluginBase;
use Drupal\access_filter\Plugin\ConditionInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Filter condition using request URI.
 *
 * @AccessFilterCondition(
 *   id = "uri",
 *   description = @Translation("Request URI with query parameters."),
 *   examples = {
 *     "- { type: uri, uri: '/foo/bar?param=1' }",
 *     "- { type: uri, uri: '/\/foo\/bar\?param=[0-9]{2}/i', regex: 1 }"
 *   }
 * )
 */
class UriCondition extends PluginBase implements ConditionInterface, ContainerFactoryPluginInterface {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition
    );
  }

  /**
   * {@inheritdoc}
   */
  public function summary() {
    $regex = !empty($this->configuration['regex']) ? ' [Regex]' : '';
    return $this->configuration['uri'] . $regex;
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfiguration(array $configuration) {
    $errors = [];

    if (!isset($configuration['uri']) || !strlen($configuration['uri'])) {
      $errors[] = $this->t("'@property' is required.", ['@property' => 'uri']);
    }

    return $errors;
  }

  /**
   * {@inheritdoc}
   */
  public function isMatched(Request $request) {
    $uri = $request->getPathInfo();
    $qs = $request->getQueryString();
    if ($qs !== NULL) {
      $uri .= '?' . $qs;
    }

    if (empty($this->configuration['regex'])) {
      return ($uri == $this->configuration['uri']);
    }
    else {
      return (bool) preg_match($this->configuration['uri'], $uri);
    }
  }

}
